/*
  Detailed information about each file, as provided by the `p4 fstat` command.

*/
function FstatCommand(data) {

    Object.defineProperties(this, {
        /*
          Depot path to file.
          For files containing special characters, the filename is displayed containing the ASCII expression of the character’s hexadecimal value.

        */
        "depotFile": {
            value: data ? data.depotFile : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Name in depot of moved to/from file.

        */
        "movedFile": {
            value: data ? data.movedFile : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Set to `shelved` if file is shelved.
        */
        "shelved": {
            value: data ? data.shelved : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Action taken at head revision, if in depot.

          One of: add, edit, delete, branch, move/add, move/delete, integrate, import, purge, or archive.

        */
        "headAction": {
            value: data ? data.headAction : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Head revision changelist number, if in depot.

        */
        "headChange": {
            value: data ? data.headChange : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Head revision number, if in depot.

        */
        "headRev": {
            value: data ? data.headRev : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Head revision type, if in depot.

        */
        "headType": {
            value: data ? data.headType : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Head charset, for unicode files.

        */
        "headCharset": {
            value: data ? data.headCharset : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Head revision changelist time, if in depot.
          Time is measured in seconds since 00:00:00 UTC, January 1, 1970.

        */
        "headTime": {
            enumerable: true,
            get: function() {
                if (data && data.headTime) {
                    var strVal = data.headTime;
                    return Date.parse(strVal);
                }
            }
        },
        /*
          Head revision modification time (the time that the file was last modified on the client before submit), if in depot.

        */
        "headModTime": {
            enumerable: true,
            get: function() {
                if (data && data.headModTime) {
                    var strVal = data.headModTime;
                    return Date.parse(strVal);
                }
            }
        },
        /*
          Head revision of moved file.

        */
        "movedRev": {
            value: data ? data.movedRev : undefined,
            enumerable: true,
            writable: true
        },
        /*
          MD5 digest of a file.

        */
        "digest": {
            value: data ? data.digest : undefined,
            enumerable: true,
            writable: true
        },
        /*
          File length in bytes.

        */
        "fileSize": {
            value: data ? data.fileSize : undefined,
            enumerable: true,
            writable: true
        },
        /*
          User who opened the file, if open.

        */
        "actionOwner": {
            value: data ? data.actionOwner : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The number, if any, of resovled integration records.

        */
        "resolved": {
            value: data ? data.resolved : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The number, if any, of unresolved integration records.

        */
        "unresolved": {
            value: data ? data.unresolved : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The number, if any, of re-resolvable integration records.

        */
        "reresolvable": {
            value: data ? data.reresolvable : undefined,
            enumerable: true,
            writable: true
        },
        /*
          For each user with the file open, the workspace and user with the open file.

        */
        "otherOpens": {
            value: data ? data.otherOpens : undefined,
            enumerable: true,
            writable: true
        },
        /*
          For each user with the file locked, the workspace and user holding the lock.

        */
        "otherLocks": {
            value: data ? data.otherLocks : undefined,
            enumerable: true,
            writable: true
        },
        /*
          For each user with the file open, the action taken.

        */
        "otherActions": {
            value: data ? data.otherActions : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The changelist number with this file open.

        */
        "otherChanges": {
            value: data ? data.otherChanges : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Pending integration action.

        */
        "resolveActions": {
            value: data ? data.resolveActions : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Pending base files.

        */
        "resolveBaseFiles": {
            value: data ? data.resolveBaseFiles : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Pending base revision numbers.

        */
        "resolveBaseRevs": {
            value: data ? data.resolveBaseRevs : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Pending from files.

        */
        "resolveFromFiles": {
            value: data ? data.resolveFromFiles : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Pending starting revisions.

        */
        "resolveStartFromRevs": {
            value: data ? data.resolveStartFromRevs : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Pending ending revisions.

        */
        "resolveEndFromRevs": {
            value: data ? data.resolveEndFromRevs : undefined,
            enumerable: true,
            writable: true
        }
    });

}

module.exports = FstatCommand;
