/*
*/
function LabelsCommand(data) {

    Object.defineProperties(this, {
        /*
          The label name.

        */
        "label": {
            value: data ? data.label : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The date the label specification was last modified.

        */
        "update": {
            enumerable: true,
            get: function() {
                if (data && data.update) {
                    var strVal = data.update;
                    return Date.parse(strVal);
                }
            }
        },
        /*
          The date and time the label was last accessed, either by running p4 labelsync on the label, or by otherwise referring to a file with the label revision specifier @label.
          (Note: Reloading a label with p4 reload does not affect the access time.)

        */
        "access": {
            enumerable: true,
            get: function() {
                if (data && data.access) {
                    var strVal = data.access;
                    return Date.parse(strVal);
                }
            }
        },
        /*
          The label’s owner.
          By default, the user who created the label.
          Only the owner of a label can update which files are tagged with the label.

          The specified owner does not have to be a Perforce user.
          You might want to use an arbitrary name if the user does not yet exist, or if you have deleted the user and need a placeholder until you can assign the spec to a new user.

        */
        "owner": {
            value: data ? data.owner : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Options to control behavior and storage location of labels.

          - locked or unlocked: If the label is locked, the list of files tagged with the label cannot be changed with p4 labelsync.

          - autoreload or noautoreload. For static labels, if noautoreload is set, the label is stored in db.label, and if autoreload is set, it is stored in the unload depot. This option is ignored for automatic labels. Storing labels in the unload depot can improve performance on sites that make extremely heavy use of labels.

        */
        "options": {
            value: data ? data.options : undefined,
            enumerable: true,
            writable: true
        },
        /*
          An optional description of the label’s purpose.

        */
        "description": {
            value: data ? data.description : undefined,
            enumerable: true,
            writable: true
        }
    });

}

module.exports = LabelsCommand;
