/*
*/
function ServersCommand(data) {

    Object.defineProperties(this, {
        /*
          A unique identifier for this server.
          This must match the contents of the server’s `server.id` file as defined by the p4 serverid command.
          If the server type is identifier, the server id specifies the name of the cluster.

        */
        "serverID": {
            value: data ? data.serverID : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Server executable type.

          One of the following: `server`, `proxy`, `broker`, `identifier`, `admin`.

          Each type may offer one or more services, defined in the `services` property.

        */
        "type": {
            value: data ? data.type : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The `server` type server provides the following services:

          - standard - a standard Perforce server
          - replica - a read-only replica server
          - commit-server - central server in distributed installation
          - edge-server - node in distributed installation
          - forwarding-replica - a replica configured to forward commands that involve database writes to a master server
          - build-server - a replica that supports build automation and build farm integration
          - P4AUTH - a server that provides authentication
          - P4CHANGE - a server that provides change numbering
          - depot-master - commit-server with automated failover
          - depot-standby - standby replica of the depot-master
          - workspace-server - node in a cluster installation
          - standby - read-only replica server that uses p4 journalcopy
          - forwarding-standby - forwarding replica server that uses p4 journalcopy

          The `proxy` type server provides a p4p caching proxy.

          The `broker` type server provides the following services:

          - broker - a p4broker process
          - workspace-router - routing broker for a cluster

          The services field for the `identifier` type server specifies the existence of the cluster, and has the value `cluster`.
          The name of the cluster is then drawn from the ServerID field.

          The `admin` type server provides the following services:

          - hxca-server - the admin server for a Helix cluster.
          - zookeeper-server - ZooKeeper server for a cluster

        */
        "services": {
            value: data ? data.services : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The P4NAME associated with this server.
          You can leave this blank or you can set it to the same value as the serverid.

        */
        "name": {
            value: data ? data.name : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The P4PORT used by this server.

        */
        "address": {
            value: data ? data.address : undefined,
            enumerable: true,
            writable: true
        },
        /*
          An optional description for this server.

        */
        "description": {
            value: data ? data.description : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The service user name used by the server.

        */
        "user": {
            value: data ? data.user : undefined,
            enumerable: true,
            writable: true
        }
    });

}

module.exports = ServersCommand;
